@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -22,13 +22,12 @@
 #define __APPSTREAM_H
 
 #define __APPSTREAM_H_INSIDE__
-#ifdef __cplusplus
-extern "C" {
-#endif
 
+#include <as-version.h>
 #include <as-context.h>
 #include <as-component.h>
 #include <as-enums.h>
+#include <as-enum-types.h>
 #include <as-provided.h>
 #include <as-metadata.h>
 #include <as-pool.h>
@@ -48,16 +47,15 @@ extern "C" {
 #include <as-launchable.h>
 #include <as-relation.h>
 #include <as-issue.h>
+#include <as-review.h>
 
 #include <as-validator.h>
 #include <as-validator-issue.h>
 
 #include <as-utils.h>
+#include <as-vercmp.h>
 #include <as-spdx.h>
 
-#ifdef __cplusplus
-};
-#endif
 #undef __APPSTREAM_H_INSIDE__
 
 #endif /* __APPSTREAM_H */
