@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2014-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -36,15 +36,13 @@
 #include <libxml/parser.h>
 #include <string.h>
 
-#include <libsoup/soup.h>
-#include <libsoup/soup-status.h>
-
 #include "as-validator.h"
 #include "as-validator-issue.h"
 #include "as-validator-issue-tag.h"
 
 #include "as-utils.h"
 #include "as-utils-private.h"
+#include "as-curl.h"
 #include "as-vercmp.h"
 #include "as-spdx.h"
 #include "as-component.h"
@@ -62,7 +60,7 @@ typedef struct
 	gchar		*current_fname;
 
 	gboolean	check_urls;
-	SoupSession	*soup_session;
+	AsCurl		*acurl;
 } AsValidatorPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsValidator, as_validator, G_TYPE_OBJECT)
@@ -99,7 +97,6 @@ as_validator_init (AsValidator *validator)
 							g_str_equal,
 							g_free,
 							(GDestroyNotify) g_ptr_array_unref);
-	priv->soup_session = NULL;
 	priv->current_fname = NULL;
 	priv->current_cpt = NULL;
 	priv->check_urls = FALSE;
@@ -123,8 +120,8 @@ as_validator_finalize (GObject *object)
 	if (priv->current_cpt != NULL)
 		g_object_unref (priv->current_cpt);
 
-	if (priv->soup_session != NULL)
-		g_object_unref (priv->soup_session);
+	if (priv->acurl != NULL)
+		g_object_unref (priv->acurl);
 
 	G_OBJECT_CLASS (as_validator_parent_class)->finalize (object);
 }
@@ -298,26 +295,21 @@ static gboolean
 as_validator_setup_networking (AsValidator *validator)
 {
 	AsValidatorPrivate *priv = GET_PRIVATE (validator);
+	g_autoptr(GError) tmp_error = NULL;
 
 	/* check if we are already initialized */
-	if (priv->soup_session != NULL)
+	if (priv->acurl != NULL)
 		return TRUE;
 
 	/* don't initialize if no URLs should be checked */
 	if (!priv->check_urls)
 		return TRUE;
 
-	priv->soup_session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT,
-							    "appstream-validator",
-							    SOUP_SESSION_TIMEOUT,
-							    90,
-							    NULL);
-	if (priv->soup_session == NULL) {
-		g_critical ("Failed to set up networking support");
+	priv->acurl = as_curl_new (&tmp_error);
+	if (priv->acurl == NULL) {
+		g_critical ("Failed to set up networking support: %s", tmp_error->message);
 		return FALSE;
 	}
-	soup_session_add_feature_by_type (priv->soup_session,
-					  SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
 	return TRUE;
 }
 
@@ -331,9 +323,7 @@ static gboolean
 as_validator_validate_web_url (AsValidator *validator, xmlNode *node, const gchar *url, const gchar *tag)
 {
 	AsValidatorPrivate *priv = GET_PRIVATE (validator);
-	guint status_code;
-	g_autoptr(SoupMessage) msg = NULL;
-	g_autoptr(SoupURI) base_uri = NULL;
+	g_autoptr(GError) tmp_error = NULL;
 
 	/* we don't check mailto URLs */
 	if (g_str_has_prefix (url, "mailto:"))
@@ -347,52 +337,30 @@ as_validator_validate_web_url (AsValidator *validator, xmlNode *node, const gcha
 		return FALSE;
 	}
 
-	/* do nothing and assume the URL exists if we shouldn't check URLs */
-	if (!priv->check_urls)
-		return TRUE;
-
-	g_debug ("Checking URL: %s\n", url);
-	base_uri = soup_uri_new (url);
-	if (!SOUP_URI_VALID_FOR_HTTP (base_uri)) {
+	if (!as_curl_is_url (url)) {
 		as_validator_add_issue (validator, node, tag,
 					"%s - %s",
 					url,
 					_("URL format is invalid."));
 		return FALSE;
 	}
-	msg = soup_message_new_from_uri (SOUP_METHOD_GET, base_uri);
-	if (msg == NULL) {
-		g_warning ("Failed to setup HTTP GET message for URL.");
-		return FALSE;
-	}
 
-	/* try to download the file */
-	status_code = soup_session_send_message (priv->soup_session, msg);
-	if (SOUP_STATUS_IS_TRANSPORT_ERROR (status_code)) {
+	/* do nothing and assume the URL exists if we shouldn't check URLs */
+	if (!priv->check_urls)
+		return TRUE;
+
+	g_debug ("Checking URL availability: %s\n", url);
+
+	/* try to download first few bytes of the file, get error if that fails */
+	if (!as_curl_check_url_exists (priv->acurl, url, &tmp_error)) {
 		as_validator_add_issue (validator, node, tag,
 					"%s - %s",
 					url,
-					soup_status_get_phrase (status_code));
-		return FALSE;
-	} else if (status_code != SOUP_STATUS_OK) {
-		as_validator_add_issue (validator, node, tag,
-					"%s - HTTP %d: %s",
-					url,
-					status_code, soup_status_get_phrase(status_code));
+					tmp_error->message);
 		return FALSE;
 	}
 
-	/* check if it's a zero sized file */
-	if (msg->response_body->length == 0) {
-		as_validator_add_issue (validator, node, tag,
-					"%s - %s",
-					url,
-					/* TRANSLATORS: We tried to download from an URL, but the retrieved data was empty */
-					_("Retrieved file size was zero."));
-		return FALSE;
-	}
-
-	/* we we din't get a zero-length file, we just assume everything is fine here */
+	/* if we we din't get a zero-length file, we just assume everything is fine here */
 	return TRUE;
 }
 
@@ -434,7 +402,7 @@ as_validator_check_type_property (AsValidator *validator, AsComponent *cpt, xmlN
 {
 	gchar *prop;
 	gchar *content;
-	prop = (gchar*) xmlGetProp (node, (xmlChar*) "type");
+	prop = as_xml_get_prop_value (node, "type");
 	content = (gchar*) xmlNodeGetContent (node);
 	if (prop == NULL) {
 		as_validator_add_issue (validator, node,
@@ -568,7 +536,7 @@ as_validator_check_nolocalized (AsValidator *validator, xmlNode* node, const gch
 {
 	g_autofree gchar *lang = NULL;
 
-	lang = (gchar*) xmlGetProp (node, (xmlChar*) "lang");
+	lang = as_xml_get_prop_value (node, "lang");
 	if (lang != NULL) {
 		as_validator_add_issue (validator,
 					node,
@@ -723,7 +691,7 @@ as_validator_check_appear_once (AsValidator *validator, xmlNode *node, GHashTabl
 
 	/* generate tag-id to make a unique identifier for localized and unlocalized tags */
 	node_name = (const gchar*) node->name;
-	lang = (gchar*) xmlGetProp (node, (xmlChar*) "lang");
+	lang = as_xml_get_prop_value (node, "lang");
 	if (lang == NULL)
 		tag_id = g_strdup (node_name);
 	else
@@ -966,7 +934,7 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 		if (iter->type != XML_ELEMENT_NODE)
 			continue;
 
-		scr_kind_str = (gchar*) xmlGetProp (iter, (xmlChar*) "type");
+		scr_kind_str = as_xml_get_prop_value (iter, "type");
 		if (g_strcmp0 (scr_kind_str, "default") == 0)
 			default_screenshot = TRUE;
 
@@ -1035,7 +1003,7 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 								video_url);
 				}
 
-				codec_str = (gchar*) xmlGetProp (iter2, (xmlChar*) "codec");
+				codec_str = as_xml_get_prop_value (iter2, "codec");
 				if (codec_str == NULL) {
 					as_validator_add_issue (validator, iter2, "screenshot-video-codec-missing", NULL);
 				} else {
@@ -1044,7 +1012,7 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 						as_validator_add_issue (validator, iter2, "screenshot-video-codec-invalid", codec_str);
 				}
 
-				container_str = (gchar*) xmlGetProp (iter2, (xmlChar*) "container");
+				container_str = as_xml_get_prop_value (iter2, "container");
 				if (container_str == NULL) {
 					as_validator_add_issue (validator, iter2, "screenshot-video-container-missing", NULL);
 				} else {
@@ -1096,15 +1064,18 @@ as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, A
 		const gchar *node_name;
 		g_autofree gchar *content = NULL;
 		g_autofree gchar *version = NULL;
-		gboolean can_have_version;
+		g_autofree gchar *compare_str = NULL;
+		gboolean can_have_version = FALSE;
+		gboolean can_have_compare = FALSE;
 		AsRelationItemKind item_kind;
+		AsRelationCompare compare;
 
 		/* discard spaces */
 		if (iter->type != XML_ELEMENT_NODE)
 			continue;
 		node_name = (const gchar*) iter->name;
 		content = as_xml_get_node_value (iter);
-		g_strstrip (content);
+		as_strstripnl (content);
 
 		item_kind = as_relation_item_kind_from_string (node_name);
 		if (item_kind == AS_RELATION_ITEM_KIND_UNKNOWN) {
@@ -1132,20 +1103,25 @@ as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, A
 		}
 
 		switch (item_kind) {
-		case AS_RELATION_ITEM_KIND_MEMORY:
 		case AS_RELATION_ITEM_KIND_MODALIAS:
 		case AS_RELATION_ITEM_KIND_CONTROL:
 			can_have_version = FALSE;
+			can_have_compare = FALSE;
+			break;
+		case AS_RELATION_ITEM_KIND_MEMORY:
+		case AS_RELATION_ITEM_KIND_DISPLAY_LENGTH:
+			can_have_version = FALSE;
+			can_have_compare = TRUE;
 			break;
 		default:
 			can_have_version = TRUE;
+			can_have_compare = TRUE;
 		}
 
-		version = (gchar*) xmlGetProp (iter, (xmlChar*) "version");
+		version = as_xml_get_prop_value (iter, "version");
+		compare_str = as_xml_get_prop_value (iter, "compare");
+		compare = as_relation_compare_from_string (compare_str);
 		if (version != NULL) {
-			AsRelationCompare compare;
-			g_autofree gchar *compare_str = (gchar*) xmlGetProp (iter, (xmlChar*) "compare");
-
 			if (!can_have_version) {
 				as_validator_add_issue (validator, iter,
 						"relation-item-has-version",
@@ -1157,13 +1133,16 @@ as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, A
 				as_validator_add_issue (validator, iter, "relation-item-missing-compare", NULL);
 				continue;
 			}
+		}
 
-			compare = as_relation_compare_from_string (compare_str);
-			if (compare == AS_RELATION_COMPARE_UNKNOWN) {
-				as_validator_add_issue (validator, iter,
-							"relation-item-invalid-vercmp",
-							compare_str);
-			}
+		if (can_have_compare && compare == AS_RELATION_COMPARE_UNKNOWN) {
+			as_validator_add_issue (validator, iter,
+						"relation-item-invalid-vercmp",
+						compare_str);
+		} else if (!can_have_compare && compare_str != NULL) {
+			as_validator_add_issue (validator, iter,
+						"relation-item-has-vercmp",
+						compare_str);
 		}
 
 		if (kind == AS_RELATION_KIND_REQUIRES) {
@@ -1173,9 +1152,24 @@ as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, A
 				as_validator_add_issue (validator, iter, "relation-control-in-requires", NULL);
 		}
 
+		/* check input control names for sanity */
 		if (item_kind == AS_RELATION_ITEM_KIND_CONTROL) {
 			if (as_control_kind_from_string (content) == AS_CONTROL_KIND_UNKNOWN)
-				as_validator_add_issue (validator, iter, "relation-control-value-unknown", content);
+				as_validator_add_issue (validator, iter, "relation-control-value-invalid", content);
+		}
+
+		/* check display length for sanity */
+		if (item_kind == AS_RELATION_ITEM_KIND_DISPLAY_LENGTH) {
+			g_autofree gchar *side_str = NULL;
+			if (as_display_length_kind_from_string (content) == AS_DISPLAY_LENGTH_KIND_UNKNOWN) {
+				/* no text name, but we still may have an integer */
+				if (g_ascii_strtoll (content, NULL, 10) == 0)
+					as_validator_add_issue (validator, iter, "relation-display-length-value-invalid", content);
+			}
+
+			side_str = as_xml_get_prop_value (iter, "side");
+			if (as_display_side_kind_from_string (side_str) == AS_DISPLAY_SIDE_KIND_UNKNOWN)
+				as_validator_add_issue (validator, iter, "relation-display-length-side-property-invalid", side_str);
 		}
 	}
 }
@@ -1529,7 +1523,7 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 	as_validator_set_current_cpt (validator, cpt);
 
 	/* check if component type is valid */
-	cpttype = (gchar*) xmlGetProp (root, (xmlChar*) "type");
+	cpttype = as_xml_get_prop_value (root, (xmlChar*) "type");
 	if (cpttype != NULL) {
 		if (as_component_kind_from_string (cpttype) == AS_COMPONENT_KIND_UNKNOWN) {
 			as_validator_add_issue (validator, root,
@@ -1575,7 +1569,7 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 		node_content = (gchar*) xmlNodeGetContent (iter);
 
 		if (g_strcmp0 (node_name, "id") == 0) {
-			g_autofree gchar *prop = (gchar*) xmlGetProp (iter, (xmlChar*) "type");
+			g_autofree gchar *prop = as_xml_get_prop_value (iter, (xmlChar*) "type");
 			if (prop != NULL) {
 				as_validator_add_issue (validator, iter, "id-tag-has-type", node_content);
 			}
@@ -1679,6 +1673,9 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 		} else if (g_strcmp0 (node_name, "mimetypes") == 0) {
 			as_validator_check_appear_once (validator, iter, found_tags);
 			as_validator_check_children_quick (validator, iter, "mimetype", FALSE);
+			as_validator_add_issue (validator, iter,
+						"mimetypes-tag-deprecated",
+						NULL);
 		} else if (g_strcmp0 (node_name, "provides") == 0) {
 			as_validator_check_appear_once (validator, iter, found_tags);
 			as_validator_check_provides (validator, iter, cpt);
